@@ -1,4 +1,6 @@
-/* GDM - The GNOME Display Manager
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ *
+ * GDM - The GNOME Display Manager
  * Copyright (C) 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -33,8 +35,8 @@
 #include <sys/wait.h>
 #include <sys/resource.h>
 #include <strings.h>
+#include <string.h>
 #include <signal.h>
-#include <syslog.h>
 #include <errno.h>
 #include <time.h>
 #include <ctype.h>
@@ -48,7 +50,12 @@
 #include "auth.h"
 #include "slave.h"
 #include "getvt.h"
-#include "gdmconfig.h"
+
+#include "gdm-common.h"
+#include "gdm-log.h"
+#include "gdm-daemon-config.h"
+
+#include "gdm-socket-protocol.h"
 
 /* Local prototypes */
 static void gdm_server_spawn (GdmDisplay *d, const char *vtarg);
@@ -56,14 +63,11 @@ static void gdm_server_usr1_handler (gint);
 static void gdm_server_child_handler (gint);
 static char * get_font_path (const char *display);
 
-extern pid_t extra_process;
-extern int extra_status;
-extern int gdm_in_signal;
-
 /* Global vars */
 static GdmDisplay *d = NULL;
 static gboolean server_signal_notified = FALSE;
 static int server_signal_pipe[2];
+static int gdm_in_signal = 0;
 
 static void do_server_wait (GdmDisplay *d);
 static gboolean setup_server_wait (GdmDisplay *d);
@@ -141,6 +145,8 @@ gdm_exec_fbconsole (GdmDisplay *disp)
         argv[2] = disp->name;
         argv[3] = NULL;
 
+	g_debug ("Forking fbconsole");
+
         pid = fork ();
         if (pid == 0) {
                 gdm_close_all_descriptors (0 /* from */, -1 /* except */, -1 /* except2 */)
@@ -371,7 +377,7 @@ busy_ask_user (GdmDisplay *disp)
 static gboolean
 display_parent_no_connect (GdmDisplay *disp)
 {
-	char *logname = gdm_make_filename (gdm_get_value_string (GDM_KEY_LOG_DIR), d->name, ".log");
+	char *logname = gdm_make_filename (gdm_daemon_config_get_value_string (GDM_KEY_LOG_DIR), d->name, ".log");
 	FILE *fp;
 	char buf[256];
 	char *getsret;
@@ -392,7 +398,7 @@ display_parent_no_connect (GdmDisplay *disp)
 		 * version 3 specific (I don't have xfree v4 to test this),
 		 * of course additions are welcome to make this more robust */
 		if (strstr (buf, "Unable to open display \"") == buf) {
-			gdm_error (_("Display '%s' cannot be opened by Xnest"),
+			gdm_error (_("Display '%s' cannot be opened by nested display"),
 				   ve_sure_string (disp->parent_disp));
 			VE_IGNORE_EINTR (fclose (fp));
 			return TRUE;
@@ -403,7 +409,7 @@ display_parent_no_connect (GdmDisplay *disp)
 static gboolean
 display_busy (GdmDisplay *disp)
 {
-	char *logname = gdm_make_filename (gdm_get_value_string (GDM_KEY_LOG_DIR), d->name, ".log");
+	char *logname = gdm_make_filename (gdm_daemon_config_get_value_string (GDM_KEY_LOG_DIR), d->name, ".log");
 	FILE *fp;
 	char buf[256];
 	char *getsret;
@@ -458,7 +464,7 @@ open_another_logfile (char buf[256], FILE **fp)
 static int
 display_vt (GdmDisplay *disp)
 {
-	char *logname = gdm_make_filename (gdm_get_value_string (GDM_KEY_LOG_DIR), d->name, ".log");
+	char *logname = gdm_make_filename (gdm_daemon_config_get_value_string (GDM_KEY_LOG_DIR), d->name, ".log");
 	FILE *fp;
 	char buf[256];
 	gboolean switched = FALSE;
@@ -559,12 +565,12 @@ do_server_wait (GdmDisplay *d)
 		     * just wait a few seconds and hope things just work,
 		     * fortunately there is no such case yet and probably
 		     * never will, but just for code anality's sake */
-		    gdm_sleep_no_signal (gdm_get_value_int(GDM_KEY_XSERVER_TIMEOUT));
+		    gdm_sleep_no_signal (gdm_daemon_config_get_value_int(GDM_KEY_XSERVER_TIMEOUT));
 	    } else if (d->server_uid != 0) {
 		    int i;
 
 		    /* FIXME: This is not likely to work in reinit,
-		       but we never reinit Xnest servers nowdays,
+		       but we never reinit Nested servers nowdays,
 		       so that's fine */
 
 		    /* if we're running the server as a non-root, we can't
@@ -579,7 +585,7 @@ do_server_wait (GdmDisplay *d)
 		    for (i = 0;
 			 d->dsp == NULL &&
 			 d->servstat == SERVER_PENDING &&
-			 i < gdm_get_value_int(GDM_KEY_XSERVER_TIMEOUT);
+			 i < gdm_daemon_config_get_value_int(GDM_KEY_XSERVER_TIMEOUT);
 			 i++) {
 			    d->dsp = XOpenDisplay (d->name);
 			    if (d->dsp == NULL)
@@ -602,7 +608,7 @@ do_server_wait (GdmDisplay *d)
 			    struct timeval tv;
 
 			    /* Wait up to GDM_KEY_XSERVER_TIMEOUT seconds. */
-			    tv.tv_sec = MAX (1, gdm_get_value_int(GDM_KEY_XSERVER_TIMEOUT) 
+			    tv.tv_sec = MAX (1, gdm_daemon_config_get_value_int(GDM_KEY_XSERVER_TIMEOUT) 
 			    	- (time (NULL) - t));
 			    tv.tv_usec = 0;
 
@@ -615,7 +621,7 @@ do_server_wait (GdmDisplay *d)
 				    VE_IGNORE_EINTR (read (server_signal_pipe[0], buf, 4));
 			    }
 			    if ( ! server_signal_notified &&
-				t + gdm_get_value_int(GDM_KEY_XSERVER_TIMEOUT) < time (NULL)) {
+				t + gdm_daemon_config_get_value_int(GDM_KEY_XSERVER_TIMEOUT) < time (NULL)) {
 				    gdm_debug ("do_server_wait: Server timeout");
 				    d->servstat = SERVER_TIMEOUT;
 				    server_signal_notified = TRUE;
@@ -738,7 +744,7 @@ gdm_server_start (GdmDisplay *disp,
     if (SERVER_IS_FLEXI (d) ||
 	treat_as_flexi) {
 	    flexi_disp = gdm_get_free_display
-		    (MAX (gdm_get_high_display_num () + 1, min_flexi_disp) /* start */,
+		    (MAX (gdm_daemon_config_get_high_display_num () + 1, min_flexi_disp) /* start */,
 		     d->server_uid /* server uid */);
 
 	    g_free (d->name);
@@ -871,7 +877,7 @@ gdm_server_start (GdmDisplay *disp,
 			    return gdm_server_start (d,
 						     FALSE /*try_again_if_busy */,
 						     TRUE /* treat as flexi */,
-						     gdm_get_high_display_num () + 1,
+						     gdm_daemon_config_get_high_display_num () + 1,
 						     flexi_retries - 1);
 		    }
 		    _exit (DISPLAY_REMANAGE);
@@ -922,7 +928,7 @@ safer_rename (const char *a, const char *b)
 static void
 rotate_logs (const char *dname)
 {
-	gchar *logdir = gdm_get_value_string (GDM_KEY_LOG_DIR);
+	const gchar *logdir = gdm_daemon_config_get_value_string (GDM_KEY_LOG_DIR);
 
 	/* I'm too lazy to write a loop */
 	char *fname4 = gdm_make_filename (logdir, dname, ".log.4");
@@ -953,49 +959,97 @@ gdm_server_resolve (GdmDisplay *disp)
 
 	bin = ve_first_word (disp->command);
 	if (bin != NULL && bin[0] != '/') {
-		svr = gdm_find_xserver (bin);
+		svr = gdm_daemon_config_find_xserver (bin);
 	}
 	g_free (bin);
 	return svr;
 }
 
 
-char **
+static char **
+vector_merge (char * const *v1,
+	      int           len1,
+	      char * const *v2,
+	      int           len2)
+{
+	int argc, i;
+	char **argv;
+
+	if (v1 == NULL && v2 == NULL)
+		return NULL;
+
+	argc = len1 + len2;
+
+	argv = g_new (char *, argc + 1);
+	for (i = 0; i < len1; i++)
+		argv[i] = g_strdup (v1[i]);
+	for (; i < argc; i++)
+		argv[i] = g_strdup (v2[i - len1]);
+	argv[i] = NULL;
+
+	return argv;
+}
+
+gboolean
 gdm_server_resolve_command_line (GdmDisplay *disp,
-				 gboolean resolve_flags,
-				 const char *vtarg)
+				 gboolean    resolve_flags,
+				 const char *vtarg,
+				 int        *argcp,
+				 char     ***argvp)
 {
 	char *bin;
+	int    argc;
 	char **argv;
 	int len;
 	int i;
 	gboolean gotvtarg = FALSE;
 	gboolean query_in_arglist = FALSE;
 
+        argv = NULL;
+
 	bin = ve_first_word (disp->command);
 	if (bin == NULL) {
+		const char *str;
+
 		gdm_error (_("Invalid server command '%s'"), disp->command);
-		argv = ve_split (gdm_get_value_string (GDM_KEY_STANDARD_XSERVER));
+		str = gdm_daemon_config_get_value_string (GDM_KEY_STANDARD_XSERVER);
+       		g_shell_parse_argv (str, &argc, &argv, NULL);
 	} else if (bin[0] != '/') {
-		GdmXserver *svr = gdm_find_xserver (bin);
+		GdmXserver *svr = gdm_daemon_config_find_xserver (bin);
 		if (svr == NULL) {
+			const char *str;
+
 			gdm_error (_("Server name '%s' not found; "
 				     "using standard server"), bin);
-			argv = ve_split (gdm_get_value_string (GDM_KEY_STANDARD_XSERVER));
+			str = gdm_daemon_config_get_value_string (GDM_KEY_STANDARD_XSERVER);
+			g_shell_parse_argv (str, &argc, &argv, NULL);
+
 		} else {
-			char **svr_command =
-				ve_split (ve_sure_string (svr->command));
-			argv = ve_split (disp->command);
+			char **svr_command;
+			const char *str;
+			int svr_argc;
+
+			str = ve_sure_string (svr->command);
+			svr_command = NULL;
+			g_shell_parse_argv (str, &svr_argc, &svr_command, NULL);
+
+			g_shell_parse_argv (disp->command, &argc, &argv, NULL);
+
 			if (argv[0] == NULL || argv[1] == NULL) {
 				g_strfreev (argv);
 				argv = svr_command;
+				argc = svr_argc;
 			} else {
 				char **old_argv = argv;
-				argv = ve_vector_merge (svr_command,
-							&old_argv[1]);
+				argv = vector_merge (svr_command,
+						     svr_argc,
+						     &old_argv[1],
+						     argc);
 				g_strfreev (svr_command);
 				g_strfreev (old_argv);
-			} 
+
+				argc += svr_argc;
+			}
 
 			if (resolve_flags) {
 				/* Setup the handled function */
@@ -1009,7 +1063,7 @@ gdm_server_resolve_command_line (GdmDisplay *disp,
 			}
 		}
 	} else {
-		argv = ve_split (disp->command);
+		g_shell_parse_argv (disp->command, &argc, &argv, NULL);
 	}
 
 	for (len = 0; argv != NULL && argv[len] != NULL; len++) {
@@ -1027,6 +1081,7 @@ gdm_server_resolve_command_line (GdmDisplay *disp,
 	}
 
 	argv = g_renew (char *, argv, len + 10);
+	/* shift args down one */
 	for (i = len - 1; i >= 1; i--) {
 		argv[i+1] = argv[i];
 	}
@@ -1052,7 +1107,7 @@ gdm_server_resolve_command_line (GdmDisplay *disp,
 		query_in_arglist = TRUE;
 	}
 
-	if (resolve_flags && gdm_get_value_bool (GDM_KEY_DISALLOW_TCP) && ! query_in_arglist) {
+	if (resolve_flags && gdm_daemon_config_get_value_bool (GDM_KEY_DISALLOW_TCP) && ! query_in_arglist) {
 		argv[len++] = g_strdup ("-nolisten");
 		argv[len++] = g_strdup ("tcp");
 		d->tcp_disallowed = TRUE;
@@ -1065,9 +1120,12 @@ gdm_server_resolve_command_line (GdmDisplay *disp,
 
 	argv[len++] = NULL;
 
+	*argvp = argv;
+	*argcp = len;
+
 	g_free (bin);
 
-	return argv;
+	return TRUE;
 }
 
 /**
@@ -1080,11 +1138,12 @@ gdm_server_resolve_command_line (GdmDisplay *disp,
  * since otherwise the server might not yet be looked up yet.
  */
 
-static void 
+static void
 gdm_server_spawn (GdmDisplay *d, const char *vtarg)
 {
     struct sigaction ign_signal;
     sigset_t mask;
+    int argc;
     gchar **argv = NULL;
     char *logfile;
     int logfd;
@@ -1110,15 +1169,21 @@ gdm_server_spawn (GdmDisplay *d, const char *vtarg)
     }
 
     /* Figure out the server command */
-    argv = gdm_server_resolve_command_line (d,
-					    TRUE /* resolve flags */,
-					    vtarg);
+    argv = NULL;
+    argc = 0;
+    gdm_server_resolve_command_line (d,
+				     TRUE /* resolve flags */,
+				     vtarg,
+				     &argc,
+				     &argv);
 
     command = g_strjoinv (" ", argv);
 
     /* Fork into two processes. Parent remains the gdm process. Child
      * becomes the X server. */
 
+    g_debug ("Forking X server process");
+
     gdm_sigterm_block_push ();
     pid = d->servpid = fork ();
     if (pid == 0)
@@ -1132,7 +1197,7 @@ gdm_server_spawn (GdmDisplay *d, const char *vtarg)
 	/* the pops whacked mask again */
         gdm_unset_signals ();
 
-	closelog ();
+	gdm_log_shutdown ();
 
 	/* close things */
 	gdm_close_all_descriptors (0 /* from */, -1 /* except */, -1 /* except2 */);
@@ -1143,13 +1208,13 @@ gdm_server_spawn (GdmDisplay *d, const char *vtarg)
 	gdm_open_dev_null (O_RDWR); /* open stdout - fd 1 */
 	gdm_open_dev_null (O_RDWR); /* open stderr - fd 2 */
 
-	openlog ("gdm", LOG_PID, LOG_DAEMON);
+	gdm_log_init ();
 
 	/* Rotate the X server logs */
 	rotate_logs (d->name);
 
         /* Log all output from spawned programs to a file */
-	logfile = gdm_make_filename (gdm_get_value_string (GDM_KEY_LOG_DIR), d->name, ".log");
+	logfile = gdm_make_filename (gdm_daemon_config_get_value_string (GDM_KEY_LOG_DIR), d->name, ".log");
 	VE_IGNORE_EINTR (g_unlink (logfile));
 	VE_IGNORE_EINTR (logfd = open (logfile, O_CREAT|O_TRUNC|O_WRONLY|O_EXCL, 0644));
 
@@ -1195,7 +1260,6 @@ gdm_server_spawn (GdmDisplay *d, const char *vtarg)
 	sigprocmask (SIG_SETMASK, &mask, NULL);
 
 	if (SERVER_IS_PROXY (d)) {
-		int argc = ve_vector_len (argv);
 		gboolean add_display = TRUE;
 
 		g_unsetenv ("DISPLAY");
@@ -1222,8 +1286,8 @@ gdm_server_spawn (GdmDisplay *d, const char *vtarg)
 
 		/*
 		 * Set the DISPLAY environment variable when calling
-		 * Xnest since some Xnest commands like Xephyr do not
-		 * support the -display argument.
+		 * nested server since some Xnest commands like Xephyr 
+		 * do not support the -display argument.
 		 */
 		if (add_display == TRUE) {
 			argv = g_renew (char *, argv, argc + 3);
@@ -1400,12 +1464,12 @@ gdm_server_child_handler (int signal)
  * Allocate display structure for a local X server
  */
 
-GdmDisplay * 
+GdmDisplay *
 gdm_server_alloc (gint id, const gchar *command)
 {
     gchar hostname[1024];
     GdmDisplay *d;
-    
+
     hostname[1023] = '\0';
     if (gethostname (hostname, 1023) == -1)
 	    strcpy (hostname, "localhost.localdomain");
@@ -1467,7 +1531,7 @@ gdm_server_alloc (gint id, const gchar *command)
     d->chooser_last_line = NULL;
 
     d->theme_name = NULL;
-    
+
     return d;
 }
 
@@ -1535,7 +1599,7 @@ get_font_path (const char *display)
 		if (i != 0)
 			g_string_append_c (gs, ',');
 
-	        if (gdm_get_value_bool (GDM_KEY_XNEST_UNSCALED_FONT_PATH) == TRUE)
+	        if (gdm_daemon_config_get_value_bool (GDM_KEY_XNEST_UNSCALED_FONT_PATH) == TRUE)
 			g_string_append (gs, font_path[i]);
 		else {
 			gchar *unscaled_ptr = NULL;
