@@ -24,16 +24,22 @@
 #include <stdlib.h>
 #include <librsvg/rsvg.h>
 #include <math.h>
-#include <gdk/gdkx.h>
 #include <locale.h>
 #include <glib/gi18n.h>
+#include <gdk/gdkx.h>
+#include <syslog.h>
 
 #include "gdmwm.h"
 #include "gdmcommon.h"
 #include "gdmconfig.h"
+
+#include "gdm-common.h"
+#include "gdm-daemon-config-keys.h"
+
 #include "greeter_configuration.h"
 #include "greeter_parser.h"
 #include "greeter_events.h"
+#include "gdm.h"
 
 /* FIXME: hack */
 extern GreeterItemInfo *welcome_string_info;
@@ -354,7 +360,7 @@ parse_stock (xmlNodePtr node,
         {
 	  g_free (*translated_text);
 	  *translated_text = g_strdup (_("_Restart"));
-	}
+	}  
       else if (g_ascii_strcasecmp ((char *) prop, "chooser") == 0)
         {
 	  g_free (*translated_text);
@@ -411,12 +417,32 @@ parse_stock (xmlNodePtr node,
         }
       else
         {
-          g_set_error (error,
-		       GREETER_PARSER_ERROR,
-		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad stock label type");
-	  xmlFree (prop);
-	  return FALSE;
+	  gboolean is_error = TRUE;
+	  register int i = 0;
+	    for (; i < GDM_CUSTOM_COMMAND_MAX; i++) {
+		gchar * key_string = NULL;
+		key_string = g_strdup_printf ("custom_cmd%d", i);
+		if (g_ascii_strcasecmp ((char *) prop, key_string) == 0) {
+		    g_free (*translated_text);
+		    g_free (key_string);
+		    key_string = g_strdup_printf ("%s%d=", GDM_KEY_CUSTOM_CMD_LABEL_TEMPLATE, i);
+		    *translated_text = g_strdup(gdm_config_get_string (key_string));
+		    g_free (key_string);
+		    is_error = FALSE;
+		    break;
+		}
+		g_free (key_string);
+	    }
+	    
+	    if (is_error)
+	      {
+		g_set_error (error,
+		     GREETER_PARSER_ERROR,
+		     GREETER_PARSER_ERROR_BAD_SPEC,
+		     "Bad stock label type");
+		xmlFree (prop);
+		return FALSE;
+	      }
 	}
 
       /* This is the very very very best "translation" */
@@ -576,7 +602,23 @@ parse_show (xmlNodePtr       node,
       }
       xmlFree (prop);
     }
-  
+
+  prop = xmlGetProp (node,(const xmlChar *) "min-screen-width");
+  if (prop != NULL)
+    {
+          g_warning ("minimum width is %d", info->minimum_required_screen_height);
+	  info->minimum_required_screen_width = atoi ((char *) prop);
+	  xmlFree (prop);
+    }
+
+  prop = xmlGetProp (node,(const xmlChar *) "min-screen-height");
+  if (prop != NULL)
+    {
+	  info->minimum_required_screen_height = atoi ((char *) prop);
+          g_warning ("minimum height is %d", info->minimum_required_screen_height);
+	  xmlFree (prop);
+    }
+
   prop = xmlGetProp (node,(const xmlChar *) "modes");
   if (prop != NULL)
     {
@@ -843,7 +885,7 @@ parse_state_file_pixmap (xmlNodePtr node,
   char *p;
 
   info->have_state |= (1<<state);
-  
+
   prop = xmlGetProp (node,(const xmlChar *) "file");
   if (prop)
     {
@@ -851,12 +893,43 @@ parse_state_file_pixmap (xmlNodePtr node,
 	info->data.pixmap.files[state] = g_strdup ((char *) prop);
       else
 	info->data.pixmap.files[state] = g_build_filename (file_search_path,
-					       (char *) prop,
-					       NULL);
-	
+							   (char *) prop,
+							   NULL);
+
       xmlFree (prop);
     }
-  
+
+    {
+      int i = 1;
+      char *altfile_prop_name = g_strdup_printf ("altfile%d", i);
+
+      prop = xmlGetProp (node,(const xmlChar *) altfile_prop_name);
+      while (prop) 
+	{
+	  char *filename = NULL;
+	  if (g_path_is_absolute ((char *) prop))
+	    filename = g_strdup ((char *) prop);
+	  else
+	    filename = g_build_filename (file_search_path,
+					 (char *) prop,
+					 NULL);
+
+	  if (g_file_test (filename, G_FILE_TEST_EXISTS))
+	    {
+	      if (info->data.pixmap.files[state])
+		g_free (info->data.pixmap.files[state]);
+	      info->data.pixmap.files[state] = filename;
+	    }
+	  xmlFree (prop);
+	  g_free (altfile_prop_name);
+
+	  i++;
+	  altfile_prop_name = g_strdup_printf ("altfile%d", i);
+	  prop = xmlGetProp (node,(const xmlChar *) altfile_prop_name);
+	}
+      g_free (altfile_prop_name);
+    }
+
   prop = xmlGetProp (node,(const xmlChar *) "tint");
   if (prop)
     {
@@ -870,7 +943,7 @@ parse_state_file_pixmap (xmlNodePtr node,
   if (prop)
     {
       double alpha = g_ascii_strtod ((char *) prop, &p);
-      
+
       if G_UNLIKELY ((char *)prop == p)
 	{
 	  g_set_error (error,
@@ -883,13 +956,13 @@ parse_state_file_pixmap (xmlNodePtr node,
       xmlFree (prop);
 
       if (alpha >= 1.0)
-        info->data.pixmap.alphas[state] = 0xff;
+	info->data.pixmap.alphas[state] = 0xff;
       else if (alpha < 0)
-        info->data.pixmap.alphas[state] = 0;
+	info->data.pixmap.alphas[state] = 0;
       else
-        info->data.pixmap.alphas[state] = floor (alpha * 0xff);
+	info->data.pixmap.alphas[state] = floor (alpha * 0xff);
     }
-  
+
   return TRUE;
 }
 
@@ -1186,15 +1259,17 @@ parse_state_text (xmlNodePtr node,
 static gint
 is_current_locale (const char *lang)
 {
-  const GList *l = ve_i18n_get_language_list ("LC_MESSAGES");
+  const char * const *langs;
   int score = 0;
-  
-  while (l != NULL)
+  int i;
+
+  langs = g_get_language_names ();
+
+  for (i = 0; langs[i] != NULL; i++)
     {
-      if (strcmp (l->data, lang) == 0)
+      if (strcmp (langs[i], lang) == 0)
 	return score;
 
-      l = l->next;
       score++;
     }
   return 1000;
@@ -1457,6 +1532,22 @@ parse_list (xmlNodePtr        node,
 	     GError         **error)
 {
   xmlNodePtr child;
+  xmlChar *prop;
+
+  info->data.list.combo_type = FALSE;
+  prop = xmlGetProp (node,(const xmlChar *) "combo");
+  if (prop)
+    {
+      if (strcmp ((char *) prop, "true") == 0)
+	{
+	  info->data.list.combo_type = TRUE;
+	}
+      else if (strcmp ((char *) prop, "false") == 0)
+	{
+	  info->data.list.combo_type = FALSE;
+	}
+      xmlFree (prop);
+    }
 
   child = node->children;
   while (child)
@@ -1494,15 +1585,28 @@ parse_list (xmlNodePtr        node,
       child = child->next;
     }
 
-  if (info->data.list.items != NULL) {
-    if G_UNLIKELY (strcmp (info->id, "userlist") == 0) {
+  if ((strcmp (info->id, "userlist") == 0) && (info->data.list.combo_type == TRUE)) {
       g_set_error (error,
 		   GREETER_PARSER_ERROR,
 		   GREETER_PARSER_ERROR_BAD_SPEC,
-		   "List of id userlist cannot have custom list items");
+		   "userlist doest not support combo style");
+      return FALSE;
+  } else if (info->data.list.items != NULL) {
+
+    if G_UNLIKELY (strcmp (info->id, "userlist") == 0 ||
+                   strcmp (info->id, "session")  == 0 ||
+                   strcmp (info->id, "language") == 0) {
+      g_set_error (error,
+		   GREETER_PARSER_ERROR,
+		   GREETER_PARSER_ERROR_BAD_SPEC,
+		   "List of id userlist, session, and language cannot have custom list items");
       return FALSE;
     }
     custom_items = g_list_append (custom_items, info);
+
+  } else if (strcmp (info->id, "session") == 0 ||
+             strcmp (info->id, "language") == 0) {
+    custom_items = g_list_append (custom_items, info);
   }
 
   return TRUE;
